"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.track = exports.setGTMLoaded = exports.setDisabled = exports.createAnalytics = void 0;
var _isEmpty = _interopRequireDefault(require("lodash/isEmpty"));
var _utils = require("./utils");
var _tracking = require("./tracking");
let dataCollector = [];
let forceDisable = false;
let gtmLoaded = false;
const setDataCollector = collector => {
  dataCollector.forEach(item => collector.push(item));
  dataCollector = collector;
};
const isDisabled = () => !gtmLoaded || forceDisable || (0, _utils.getDoNotTrack)(global);
const setGTMLoaded = value => {
  gtmLoaded = value;
};
exports.setGTMLoaded = setGTMLoaded;
const setDisabled = value => {
  forceDisable = value;
};
exports.setDisabled = setDisabled;
const track = (payload, done) => {
  if ((0, _isEmpty.default)(payload)) throw new Error('Tracking payload required');
  if (isDisabled()) {
    if (done) done();
    return;
  }
  let payloadOverride;
  if (done) payloadOverride = {
    ...payload,
    eventCallback: (0, _utils.ensureCalled)(done)
  };
  dataCollector.push(payloadOverride || payload);
};
exports.track = track;
const DEFAULT_GET_PAGEVIEW_PAYLOAD = () => {};

/**
 * Callback for providing additional data to the page-view event.
 *
 * @callback getPageviewPayloadCallback
 * @param {Object} options
 * @param options.store store
 * @param options.previousPage previous page
 * @param options.currentPage current page
 */

/**
 *
 * @param store
 * @param history
 * @param collector
 * @param {getPageviewPayloadCallback} getPageviewPayload
 * @returns {{startTracking: (function(): function(): void)}}
 */
const createAnalytics = function (store, history, collector) {
  let {
    getPageviewPayload = DEFAULT_GET_PAGEVIEW_PAYLOAD
  } = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : {};
  const state = store.getState();
  let currentPage = null;
  const handlePageview = newPage => {
    (0, _tracking.trackPageView)(track, store, currentPage, newPage, getPageviewPayload);
    currentPage = newPage;
  };
  const startTracking = () => {
    const unsubscribeHistory = history.listen(handlePageview);
    handlePageview(history.location);
    return () => {
      unsubscribeHistory();
    };
  };
  (0, _tracking.removeExpiredUtm)(store, state);
  (0, _tracking.generateClientId)(track, store, state);
  (0, _tracking.generateSessionId)(track, store, state);
  (0, _tracking.generateEnvironment)(track);

  // Set real data collector
  setDataCollector(collector);
  return {
    startTracking
  };
};
exports.createAnalytics = createAnalytics;