"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.trackUtm = exports.trackPageView = exports.touchSessionId = exports.removeExpiredUtm = exports.generateSessionId = exports.generateEnvironment = exports.generateClientId = exports.configureAnalytics = void 0;
var _isEmpty = _interopRequireDefault(require("lodash/isEmpty"));
var _calculations = require("nebenan-helpers/lib/calculations");
var _utils = require("./utils");
var _actions = require("./actions");
let environment;
let sessionLifetime;
let utmLifetime;
const configureAnalytics = options => {
  environment = options.environment;
  sessionLifetime = options.sessionLifetime;
  utmLifetime = options.utmLifetime;
};
exports.configureAnalytics = configureAnalytics;
const generateEnvironment = track => track({
  environment
});
exports.generateEnvironment = generateEnvironment;
const removeExpiredUtm = (store, _ref) => {
  let {
    session
  } = _ref;
  const currentUTM = session[_actions.UTM_KEY];
  if (currentUTM && (0, _utils.isExpired)(currentUTM.timestamp, utmLifetime)) {
    store.dispatch((0, _actions.deleteUtm)());
  }
};
exports.removeExpiredUtm = removeExpiredUtm;
const trackUtm = (track, _ref2) => {
  let {
    session
  } = _ref2;
  const currentUTM = session[_actions.UTM_KEY];
  if (currentUTM) track(currentUTM.keys);
};
exports.trackUtm = trackUtm;
const generateClientId = (track, store, _ref3) => {
  let {
    session
  } = _ref3;
  const clientInfo = session[_actions.CLIENT_ID_KEY];
  let clientId;
  if (!clientInfo) {
    clientId = (0, _calculations.getUID)();
    store.dispatch((0, _actions.setClientId)(clientId));
  } else {
    clientId = clientInfo.id;
  }
  track({
    client_id: clientId
  });
};
exports.generateClientId = generateClientId;
const generateSessionId = (track, store, _ref4) => {
  let {
    session
  } = _ref4;
  const sessionInfo = session[_actions.SESSION_ID_KEY];
  let sessionId;
  if (!sessionInfo || (0, _utils.isExpired)(sessionInfo.timestamp, sessionLifetime)) {
    sessionId = (0, _calculations.getUID)();
    store.dispatch((0, _actions.setSessionId)(sessionId));
  } else {
    sessionId = sessionInfo.id;
  }
  track({
    session_id: sessionId
  });
};
exports.generateSessionId = generateSessionId;
const touchSessionId = (store, _ref5) => {
  let {
    session
  } = _ref5;
  const {
    id
  } = session[_actions.SESSION_ID_KEY];
  store.dispatch((0, _actions.setSessionId)(id));
};
exports.touchSessionId = touchSessionId;
const NULL_REFERRER_URL = {
  origin: '',
  pathname: '',
  search: ''
};
const trackPageView = (track, store, previousPage, currentPage, getPayload) => {
  const query = (0, _utils.getQuery)(currentPage.search);
  const utm = (0, _utils.getUtmKeys)(query);
  if (!(0, _isEmpty.default)(utm)) store.dispatch((0, _actions.setUtm)(utm));
  const state = store.getState();
  // always read what's in the session, otherwise conversions are lost
  trackUtm(track, state);
  // Don't let sessions expire whilst still browsing
  touchSessionId(store, state);
  const url = (0, _utils.getUrlFromPage)(currentPage, global);
  let referrer = NULL_REFERRER_URL;
  if (previousPage) {
    referrer = (0, _utils.getUrlFromPage)(previousPage, global);
  } else if (document?.referrer) {
    referrer = new URL(document.referrer);
  }
  const payload = {
    ...getPayload({
      store,
      previousPage,
      currentPage
    }),
    event: 'virtual_page_view',
    virtual_page_url: url.origin + url.pathname,
    virtual_page_query: url.search.substr(1),
    referrer_url: referrer.origin + referrer.pathname,
    referrer_query: referrer.search.substr(1)
  };
  track(payload);
};
exports.trackPageView = trackPageView;