"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.isExpired = exports.getUtmKeys = exports.getUrlFromPage = exports.getQuery = exports.getDoNotTrack = exports.ensureCalled = void 0;
var _qs = require("qs");
const UTM_REGEX = /^utm_/;
const DNT_POSITIVES = ['yes', '1', 1];
const getQuery = search => (0, _qs.parse)(search.substr(1));
exports.getQuery = getQuery;
const getDoNotTrack = node => {
  let value;
  if (typeof node.navigator.doNotTrack !== 'undefined') {
    value = node.navigator.doNotTrack;
  } else if (typeof node.navigator.msDoNotTrack !== 'undefined') {
    value = node.navigator.msDoNotTrack;
  } else {
    value = node.doNotTrack;
  }
  return DNT_POSITIVES.includes(value);
};
exports.getDoNotTrack = getDoNotTrack;
const isExpired = (timestamp, limit) => Date.now() - timestamp > limit;
exports.isExpired = isExpired;
const getUtmKeys = query => Object.keys(query).reduce((result, key) => {
  if (UTM_REGEX.test(key)) result[key] = query[key];
  return result;
}, {});
exports.getUtmKeys = getUtmKeys;
const ensureCalled = function (func) {
  let timeout = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 500;
  let isCalled = false;
  let timerId = null;
  const proxy = () => {
    if (isCalled) return;
    clearTimeout(timerId);
    func();
    isCalled = true;
  };
  timerId = setTimeout(proxy, timeout);
  return proxy;
};
exports.ensureCalled = ensureCalled;
const getUrlFromPage = (_ref, window) => {
  let {
    pathname,
    search
  } = _ref;
  return new URL(pathname + search, window.location.origin);
};
exports.getUrlFromPage = getUrlFromPage;