"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getContentfulRequest = exports.formatImages = exports.formatImage = exports.createContentfulRequest = exports.configureContentful = void 0;
var _qs = require("qs");
var _network = require("nebenan-redux-tools/lib/network");
let space;
let language;
let preview = false;
let proxyUrl;
let createRequest;
const configureContentful = options => {
  space = options.space;
  language = options.language;
  preview = options.preview;
  proxyUrl = options.url;
  createRequest = options.createRequest || _network.createRequest;
};

/**
 * @deprecated use #createContentfulRequest instead
 */
exports.configureContentful = configureContentful;
const getContentfulRequest = (type, contentQuery) => {
  const {
    id,
    token,
    preview_token
  } = space;
  const access_token = preview ? preview_token : token;
  const content_type = space[`content_type_${type}`];
  const proxyQuery = {
    ...contentQuery,
    access_token,
    content_type,
    'fields.localization': language
  };
  const query_string = `/spaces/${id}/entries?${(0, _qs.stringify)(proxyQuery, {
    indices: false
  })}`;
  const query = {
    query_string
  };
  // BE is too lazy to check for value
  if (preview) query.preview = preview;
  return {
    query,
    url: proxyUrl,
    graceful: true
  };
};
exports.getContentfulRequest = getContentfulRequest;
const hasValidationErrors = payload => payload?.errors;
const createContentfulRequest = async (type, contentQuery) => {
  const payload = await createRequest(getContentfulRequest(type, contentQuery));
  if (hasValidationErrors(payload)) throw new Error(`Contentful request '${type}' contains validation errors`);
  return payload;
};
exports.createContentfulRequest = createContentfulRequest;
const formatImage = (image, assets) => {
  const ref = assets[image.sys.id];
  // optional chaining saves page crash when contentful content in staging spaces is missing
  const url = ref?.fields?.file?.url;
  if (!url) return null;
  return `https:${url}`;
};
exports.formatImage = formatImage;
const formatImages = (list, assets) => list.reduce((collection, item) => {
  const {
    id
  } = item.sys;
  const url = formatImage(item, assets);
  if (url) collection.push({
    id,
    url
  });
  return collection;
}, []);
exports.formatImages = formatImages;